@@ -497,7 +497,20 @@ static void pr_retval(struct uftrace_fstack_args *args)
 static void pr_event(struct uftrace_task_reader *task, unsigned evt_id)
 {
 	char *evt_name = event_get_name(task->h, evt_id);
-	char *evt_data = event_get_data_str(evt_id, task->args.data, false);
+	struct uftrace_symbol *sym = NULL;
+	char *evt_data;
+
+	if (evt_id == EVENT_ID_WATCH_VAR) {
+		unsigned long long addr = 0;
+
+		if (data_is_lp64(task->h))
+			memcpy(&addr, task->args.data, 8);
+		else
+			memcpy(&addr, task->args.data, 4);
+
+		sym = task_find_sym_addr(&task->h->sessions, task, task->ustack.time, addr);
+	}
+	evt_data = event_get_data_str(task->h, evt_id, task->args.data, task->args.len, sym, false);
 
 	pr_out("  %s", evt_name);
 	if (evt_data)
@@ -540,7 +553,7 @@ static void dump_raw_header(struct uftrace_dump_ops *ops, struct uftrace_data *h
 	const char *info_str[] = { "EXE_NAME",	   "EXE_BUILD_ID", "EXIT_STATUS", "CMDLINE",
 				   "CPUINFO",	   "MEMINFO",	   "OSINFO",	  "TASKINFO",
 				   "USAGEINFO",	   "LOADINFO",	   "ARG_SPEC",	  "RECORD_DATE",
-				   "PATTERN_TYPE", "VERSION" };
+				   "PATTERN_TYPE", "VERSION",	   "UTC_OFFSET" };
 
 	pr_out("uftrace file header: magic         = ");
 	for (i = 0; i < UFTRACE_MAGIC_LEN; i++)
@@ -601,8 +614,8 @@ static void dump_raw_task_rstack(struct uftrace_dump_ops *ops, struct uftrace_ta
 		name = event_get_name(task->h, frs->addr);
 
 	pr_time(frs->time);
-	pr_out("%5d: [%s] %s(%" PRIx64 ") depth: %u\n", task->tid, rstack_type(frs), name,
-	       frs->addr, frs->depth);
+	pr_out("%*d: [%s] %s(%" PRIx64 ") depth: %u\n", TASK_ID_LEN, task->tid, rstack_type(frs),
+	       name, frs->addr, frs->depth);
 	pr_hex(&raw->file_offset, frs, sizeof(*frs));
 
 	if (frs->type == UFTRACE_EVENT)
@@ -611,13 +624,15 @@ static void dump_raw_task_rstack(struct uftrace_dump_ops *ops, struct uftrace_ta
 	if (frs->more && show_args) {
 		if (frs->type == UFTRACE_ENTRY) {
 			pr_time(frs->time);
-			pr_out("%5d: [%s] length = %d\n", task->tid, "args ", task->args.len);
+			pr_out("%*d: [%s] length = %d\n", TASK_ID_LEN, task->tid, "args ",
+			       task->args.len);
 			pr_args(&task->args);
 			pr_hex(&raw->file_offset, task->args.data, ALIGN(task->args.len, 8));
 		}
 		else if (frs->type == UFTRACE_EXIT) {
 			pr_time(frs->time);
-			pr_out("%5d: [%s] length = %d\n", task->tid, "retval", task->args.len);
+			pr_out("%*d: [%s] length = %d\n", TASK_ID_LEN, task->tid, "retval",
+			       task->args.len);
 			pr_retval(&task->args);
 			pr_hex(&raw->file_offset, task->args.data, ALIGN(task->args.len, 8));
 		}
@@ -633,13 +648,13 @@ static void dump_raw_task_event(struct uftrace_dump_ops *ops, struct uftrace_tas
 	char *name = event_get_name(task->h, frs->addr);
 
 	pr_time(frs->time);
-	pr_out("%5d: [%s] %s(%" PRIx64 ") depth: %u\n", task->tid, rstack_type(frs), name,
-	       frs->addr, frs->depth);
+	pr_out("%*d: [%s] %s(%" PRIx64 ") depth: %u\n", TASK_ID_LEN, task->tid, rstack_type(frs),
+	       name, frs->addr, frs->depth);
 	pr_hex(&raw->file_offset, frs, sizeof(*frs));
 
 	if (frs->more && show_args) {
 		pr_time(frs->time);
-		pr_out("%5d: [%s] length = %d\n", task->tid, "data ", task->args.len);
+		pr_out("%*d: [%s] length = %d\n", TASK_ID_LEN, task->tid, "data ", task->args.len);
 		pr_event(task, frs->addr);
 		pr_hex(&raw->file_offset, task->args.data, ALIGN(task->args.len, 8));
 	}
@@ -692,8 +707,8 @@ static void dump_raw_kernel_rstack(struct uftrace_dump_ops *ops,
 			timestamp = ((uint64_t)upper << 27) + (lower >> 5);
 
 			pr_time(frs->time - timestamp);
-			pr_out("%5d: [%s] %s (+%" PRIu64 " nsec)\n", tid, "time ", "extend",
-			       timestamp);
+			pr_out("%*d: [%s] %s (+%" PRIu64 " nsec)\n", TASK_ID_LEN, tid, "time ",
+			       "extend", timestamp);
 
 			if (debug)
 				pr_hex(&offset, tmp, 8);
@@ -705,8 +720,8 @@ static void dump_raw_kernel_rstack(struct uftrace_dump_ops *ops,
 	}
 
 	pr_time(frs->time);
-	pr_out("%5d: [%s] %s(%" PRIx64 ") depth: %u\n", tid, rstack_type(frs), name, frs->addr,
-	       frs->depth);
+	pr_out("%*d: [%s] %s(%" PRIx64 ") depth: %u\n", TASK_ID_LEN, tid, rstack_type(frs), name,
+	       frs->addr, frs->depth);
 
 	if (debug) {
 		/* this is only needed for hex dump */
@@ -744,7 +759,8 @@ static void dump_raw_kernel_event(struct uftrace_dump_ops *ops,
 	event_data = read_kernel_event(kernel, cpu, &size);
 
 	pr_time(frs->time);
-	pr_out("%5d: [%s] %s(%ld) %.*s\n", tid, rstack_type(frs), buf, frs->addr, size, event_data);
+	pr_out("%*d: [%s] %s(%ld) %.*s\n", TASK_ID_LEN, tid, rstack_type(frs), buf, frs->addr, size,
+	       event_data);
 
 	if (debug) {
 		/* this is only needed for hex dump */
@@ -765,7 +781,7 @@ static void dump_raw_kernel_event(struct uftrace_dump_ops *ops,
 static void dump_raw_kernel_lost(struct uftrace_dump_ops *ops, uint64_t time, int tid, int losts)
 {
 	pr_time(time);
-	pr_red("%5d: [%s ]: %d events\n", tid, "lost", losts);
+	pr_red("%*d: [%s ]: %d events\n", TASK_ID_LEN, tid, "lost", losts);
 }
 
 static void dump_raw_perf_start(struct uftrace_dump_ops *ops, struct uftrace_perf_reader *perf,
@@ -788,7 +804,8 @@ static void dump_raw_perf_event(struct uftrace_dump_ops *ops, struct uftrace_per
 	char *evt_name = event_get_name(NULL, frs->addr);
 
 	pr_time(frs->time);
-	pr_out("%5d: [%s] %s(%" PRIu64 ")\n", perf->tid, rstack_type(frs), evt_name, frs->addr);
+	pr_out("%*d: [%s] %s(%" PRIu64 ")\n", TASK_ID_LEN, perf->tid, rstack_type(frs), evt_name,
+	       frs->addr);
 
 	if (debug) {
 		/* XXX: this is different from file contents */
@@ -946,6 +963,8 @@ static void dump_chrome_kernel_rstack(struct uftrace_dump_ops *ops,
 
 	tid = kernel->tids[cpu];
 	task = get_task_handle(kernel->handle, tid);
+	if (task == NULL)
+		return;
 
 	dump_chrome_task_rstack(ops, task, name);
 }
@@ -1148,6 +1167,8 @@ static void dump_flame_kernel_rstack(struct uftrace_dump_ops *ops,
 
 	tid = kernel->tids[cpu];
 	task = get_task_handle(kernel->handle, tid);
+	if (task == NULL)
+		return;
 
 	graph = graph_get_task(task, sizeof(*graph));
 
@@ -1219,6 +1240,8 @@ static void dump_graphviz_kernel_rstack(struct uftrace_dump_ops *ops,
 
 	tid = kernel->tids[cpu];
 	task = get_task_handle(kernel->handle, tid);
+	if (task == NULL)
+		return;
 
 	graph = graph_get_task(task, sizeof(*graph));
 
@@ -1295,6 +1318,8 @@ static void dump_mermaid_kernel_rstack(struct uftrace_dump_ops *ops,
 
 	tid = kernel->tids[cpu];
 	task = get_task_handle(kernel->handle, tid);
+	if (task == NULL)
+		return;
 
 	graph = graph_get_task(task, sizeof(*graph));
 
