@@ -539,7 +539,7 @@ static int read_taskinfo(void *arg)
 		else if (!strncmp(&buf[9], "tids=", 5)) {
 			char *tids_str = &buf[14];
 			char *endp = tids_str;
-			int *tids = xcalloc(sizeof(*tids), info->nr_tid);
+			int *tids = xcalloc(info->nr_tid, sizeof(*tids));
 			int nr_tid = 0;
 
 			while (*endp != '\n') {
@@ -851,6 +851,41 @@ static int read_uftrace_version(void *arg)
 	return 0;
 }
 
+static int fill_utc_offset(void *arg)
+{
+	struct fill_handler_arg *fha = arg;
+	time_t current_time;
+	struct timespec ts;
+	long offset;
+
+	time(&current_time);
+	clock_gettime(clock_source, &ts);
+
+	/* calculate time offset between UTC and clock_source. */
+	offset = (long)difftime(current_time, ts.tv_sec);
+
+	dprintf(fha->fd, "utc_offset:%ld\n", offset);
+	return 0;
+}
+
+static int read_utc_offset(void *arg)
+{
+	struct read_handler_arg *rha = arg;
+	struct uftrace_data *handle = rha->handle;
+	struct uftrace_info *info = &handle->info;
+	char *buf = rha->buf;
+
+	if (fgets(buf, sizeof(rha->buf), handle->fp) == NULL)
+		return -1;
+
+	if (strncmp(buf, "utc_offset:", 11))
+		return -1;
+
+	info->utc_offset = copy_info_str(&buf[11]);
+
+	return 0;
+}
+
 struct uftrace_info_handler {
 	enum uftrace_info_bits bit;
 	int (*handler)(void *arg);
@@ -883,6 +918,7 @@ void fill_uftrace_info(uint64_t *info_mask, int fd, struct uftrace_opts *opts, i
 		{ RECORD_DATE, fill_record_date },
 		{ PATTERN_TYPE, fill_pattern_type },
 		{ VERSION, fill_uftrace_version },
+		{ UTC_OFFSET, fill_utc_offset },
 	};
 
 	for (i = 0; i < ARRAY_SIZE(fill_handlers); i++) {
@@ -926,6 +962,7 @@ int read_uftrace_info(uint64_t info_mask, struct uftrace_data *handle)
 		{ RECORD_DATE, read_record_date },
 		{ PATTERN_TYPE, read_pattern_type },
 		{ VERSION, read_uftrace_version },
+		{ UTC_OFFSET, read_utc_offset },
 	};
 
 	memset(&handle->info, 0, sizeof(handle->info));
@@ -955,6 +992,7 @@ void clear_uftrace_info(struct uftrace_info *info)
 	free(info->argspec);
 	free(info->record_date);
 	free(info->elapsed_time);
+	free(info->utc_offset);
 	free(info->uftrace_version);
 	free(info->retspec);
 	free(info->autoarg);
@@ -1177,7 +1215,7 @@ static void print_task(struct uftrace_data *handle, struct uftrace_task *t)
 	/* TIMESTAMP */
 	pr_out(" %13lu.%09lu ", t->time.stamp / NSEC_PER_SEC, t->time.stamp % NSEC_PER_SEC);
 	/* FLAGS  TID  COMM */
-	pr_out(" %s  [%6d]  %-16s ", flags, t->tid, t->comm);
+	pr_out(" %s  [%*d]  %-16s ", flags, TASK_ID_LEN, t->tid, t->comm);
 	/* DATA SIZE */
 	if (stbuf.st_size) {
 		uint64_t size_kb = stbuf.st_size / 1024;
@@ -1197,8 +1235,8 @@ static void print_task_info(struct uftrace_data *handle)
 	struct rb_node *n;
 	struct uftrace_task *t;
 
-	pr_out("#%23s  %5s  %8s  %-16s  %s\n", "TIMESTAMP     ", "FLAGS", "  TID  ", "TASK",
-	       "DATA SIZE");
+	pr_out("#%23s  %5s  %*s  %-16s  %s\n", "TIMESTAMP     ", "FLAGS", TASK_ID_LEN + 2,
+	       "   TID   ", "TASK", "DATA SIZE");
 
 	n = rb_first(&handle->sessions.tasks);
 	while (n != NULL) {
