@@ -174,13 +174,11 @@ static const char *help[] = {
 	"q             Quit",
 };
 
-#define NUM_GRAPH_FIELD 3
+#define NUM_GRAPH_FIELD 9
 
-static const char *graph_field_names[NUM_GRAPH_FIELD] = {
-	"TOTAL TIME",
-	"SELF TIME",
-	"ADDRESS",
-};
+static const char *graph_field_names[NUM_GRAPH_FIELD] = { "TOTAL TIME", "SELF TIME", "ADDRESS",
+							  "TOTAL AVG",	"SELF AVG",  "TOTAL MAX",
+							  "TOTAL MIN",	"SELF MAX",  "SELF MIN" };
 
 #define NUM_REPORT_FIELD 12
 
@@ -291,6 +289,56 @@ static void print_graph_addr(struct field_data *fd)
 	printw("%*" PRIx64, width, effective_addr(node->addr));
 }
 
+static void print_graph_total_avg(struct field_data *fd)
+{
+	struct uftrace_graph_node *node = fd->arg;
+	uint64_t d = 0;
+
+	if (node->nr_calls)
+		d = node->time / node->nr_calls;
+
+	print_time(d);
+}
+
+static void print_graph_self_avg(struct field_data *fd)
+{
+	struct uftrace_graph_node *node = fd->arg;
+	uint64_t d = 0;
+
+	if (node->nr_calls)
+		d = (node->time - node->child_time) / node->nr_calls;
+
+	print_time(d);
+}
+
+static void print_graph_total_min(struct field_data *fd)
+{
+	struct uftrace_graph_node *node = fd->arg;
+
+	print_time(node->total.min);
+}
+
+static void print_graph_total_max(struct field_data *fd)
+{
+	struct uftrace_graph_node *node = fd->arg;
+
+	print_time(node->total.max);
+}
+
+static void print_graph_self_max(struct field_data *fd)
+{
+	struct uftrace_graph_node *node = fd->arg;
+
+	print_time(node->self.max);
+}
+
+static void print_graph_self_min(struct field_data *fd)
+{
+	struct uftrace_graph_node *node = fd->arg;
+
+	print_time(node->self.min);
+}
+
 static struct display_field graph_field_total = {
 	.id = GRAPH_F_TOTAL_TIME,
 	.name = "total-time",
@@ -326,11 +374,65 @@ static struct display_field graph_field_addr = {
 	.list = LIST_HEAD_INIT(graph_field_addr.list),
 };
 
+static struct display_field graph_field_total_avg = {
+	.id = GRAPH_F_TOTAL_AVG,
+	.name = "total-avg",
+	.header = " TOTAL AVG",
+	.length = 10,
+	.print = print_graph_total_avg,
+	.list = LIST_HEAD_INIT(graph_field_total_avg.list),
+};
+
+static struct display_field graph_field_self_avg = {
+	.id = GRAPH_F_SELF_AVG,
+	.name = "self-avg",
+	.header = "  SELF AVG",
+	.length = 10,
+	.print = print_graph_self_avg,
+	.list = LIST_HEAD_INIT(graph_field_self_avg.list),
+};
+
+static struct display_field graph_field_total_min = {
+	.id = GRAPH_F_TOTAL_MIN,
+	.name = "total-min",
+	.header = " TOTAL MIN",
+	.length = 10,
+	.print = print_graph_total_min,
+	.list = LIST_HEAD_INIT(graph_field_total_min.list),
+};
+
+static struct display_field graph_field_total_max = {
+	.id = GRAPH_F_TOTAL_MAX,
+	.name = "total-max",
+	.header = " TOTAL MAX",
+	.length = 10,
+	.print = print_graph_total_max,
+	.list = LIST_HEAD_INIT(graph_field_total_max.list),
+};
+
+static struct display_field graph_field_self_max = {
+	.id = GRAPH_F_SELF_MAX,
+	.name = "self-max",
+	.header = "  SELF MAX",
+	.length = 10,
+	.print = print_graph_self_max,
+	.list = LIST_HEAD_INIT(graph_field_self_max.list),
+};
+
+static struct display_field graph_field_self_min = {
+	.id = GRAPH_F_SELF_MIN,
+	.name = "self-min",
+	.header = "  SELF MIN",
+	.length = 10,
+	.print = print_graph_self_min,
+	.list = LIST_HEAD_INIT(graph_field_self_min.list),
+};
+
 /* index of this table should be matched to display_field_id */
 static struct display_field *graph_field_table[] = {
-	&graph_field_total,
-	&graph_field_self,
-	&graph_field_addr,
+	&graph_field_total,	&graph_field_self,	&graph_field_addr,
+	&graph_field_total_avg, &graph_field_total_max, &graph_field_total_min,
+	&graph_field_self_avg,	&graph_field_self_max,	&graph_field_self_min,
 };
 
 /* clang-format off */
