@@ -147,13 +147,14 @@ struct mcount_thread_data {
 	int record_idx;
 	bool recursion_marker;
 	bool in_exception;
-	bool dead;
+	bool dead; /* mtd_dtor() called */
 	bool warned;
 	unsigned long cygprof_dummy;
 	struct mcount_ret_stack *rstack;
 	void *argbuf;
 	struct filter_control filter;
 	bool enable_cached;
+	bool exited; /* pthread_exit() called */
 	struct mcount_shmem shmem;
 	struct mcount_event event[MAX_EVENT];
 	int nr_events;
@@ -308,11 +309,8 @@ static inline void mcount_memcpy4(void *restrict dst, const void *restrict src,
 		*p++ = *q++;
 }
 
-extern void mcount_return(void);
-extern void dynamic_return(void);
-extern unsigned long plthook_return(void);
-
 extern unsigned long mcount_return_fn;
+extern unsigned long plthook_return_fn;
 
 extern struct mcount_thread_data *mcount_prepare(void);
 
@@ -351,7 +349,7 @@ struct plthook_special_func {
 
 struct plthook_skip_symbol {
 	const char *name;
-	void *addr;
+	int entry_idx; /* for mcount_arch_ops.entry[] */
 };
 
 struct plthook_data {
@@ -384,8 +382,6 @@ extern void mcount_setup_plthook(char *exename, bool nest_libcall);
 extern void setup_dynsym_indexes(struct plthook_data *pd);
 extern void destroy_dynsym_indexes(void);
 
-extern unsigned long mcount_arch_plthook_addr(struct plthook_data *pd, int idx);
-
 extern unsigned long plthook_resolver_addr;
 extern const struct plthook_skip_symbol plt_skip_syms[];
 extern size_t plt_skip_nr;
@@ -418,8 +414,8 @@ extern void mcount_arch_get_arg(struct mcount_arg_context *ctx, struct uftrace_a
 extern void mcount_arch_get_retval(struct mcount_arg_context *ctx, struct uftrace_arg_spec *spec);
 
 extern enum filter_result mcount_entry_filter_check(struct mcount_thread_data *mtdp,
-						    unsigned long child,
-						    struct uftrace_trigger *tr);
+						    unsigned long child, struct uftrace_trigger *tr,
+						    struct mcount_regs *regs);
 extern void mcount_entry_filter_record(struct mcount_thread_data *mtdp,
 				       struct mcount_ret_stack *rstack, struct uftrace_trigger *tr,
 				       struct mcount_regs *regs);
