@@ -116,13 +116,12 @@ static unsigned long __maybe_unused mcount_watchpoints;
 /* address of function will be called when a function returns */
 unsigned long mcount_return_fn;
 
+/* address of function will be called when a PLT function returns */
+unsigned long plthook_return_fn;
+
 /* do not hook return address and inject EXIT record between functions */
 bool mcount_estimate_return;
 
-__weak void dynamic_return(void)
-{
-}
-
 /* list of watch points (of global variables) */
 static LIST_HEAD(mcount_watch_list);
 
@@ -735,7 +734,8 @@ void mtd_dtor(void *arg)
 	if (mcount_estimate_return)
 		mcount_rstack_estimate_finish(mtdp);
 
-	mcount_rstack_restore(mtdp);
+	if (!mtdp->exited)
+		mcount_rstack_restore(mtdp);
 
 	if (ARCH_CAN_RESTORE_PLTHOOK || !mcount_rstack_has_plthook(mtdp)) {
 		free(mtdp->rstack);
@@ -1000,7 +1000,7 @@ static void mcount_save_filter(struct mcount_thread_data *mtdp)
 
 /* update filter state from trigger result */
 enum filter_result mcount_entry_filter_check(struct mcount_thread_data *mtdp, unsigned long child,
-					     struct uftrace_trigger *tr)
+					     struct uftrace_trigger *tr, struct mcount_regs *regs)
 {
 	int max_depth = mtdp->filter.max_depth;
 
@@ -1022,6 +1022,26 @@ enum filter_result mcount_entry_filter_check(struct mcount_thread_data *mtdp, un
 	pr_dbg3(" tr->flags: %x, filter mode: %d, count: %d/%d, depth: %d\n", tr->flags, tr->fmode,
 		mtdp->filter.in_count, mtdp->filter.out_count, mtdp->filter.depth);
 
+	if (tr->flags & TRIGGER_FL_FILTER && tr->cond.idx && regs) {
+		struct mcount_arg_context ctx;
+		struct uftrace_arg_spec spec = {
+			.idx = tr->cond.idx,
+			.fmt = ARG_FMT_AUTO,
+			.type = ARG_TYPE_INDEX,
+		};
+
+		mcount_memset4(&ctx, 0, sizeof(ctx));
+		ctx.regs = regs;
+		ctx.regions = &mtdp->mem_regions;
+		ctx.arch = &mtdp->arch;
+
+		mcount_arch_get_arg(&ctx, &spec);
+
+		/* keep the filter only if the condition is met */
+		if (!uftrace_eval_cond(&tr->cond, ctx.val.i))
+			tr->flags &= ~TRIGGER_FL_FILTER;
+	}
+
 	if (tr->flags & TRIGGER_FL_FILTER) {
 		if (tr->fmode == FILTER_MODE_IN)
 			mtdp->filter.in_count++;
@@ -1374,7 +1394,7 @@ void mcount_exit_filter_record(struct mcount_thread_data *mtdp, struct mcount_re
  */
 
 enum filter_result mcount_entry_filter_check(struct mcount_thread_data *mtdp, unsigned long child,
-					     struct uftrace_trigger *tr)
+					     struct uftrace_trigger *tr, struct mcount_regs *regs)
 {
 	if (mcount_check_rstack(mtdp))
 		return FILTER_RSTACK;
@@ -1496,7 +1516,8 @@ static int __mcount_entry(unsigned long *parent_loc, unsigned long child, struct
 	}
 
 	tr.flags = 0;
-	filtered = mcount_entry_filter_check(mtdp, child, &tr);
+	tr.cond.idx = 0;
+	filtered = mcount_entry_filter_check(mtdp, child, &tr, regs);
 	if (filtered != FILTER_IN) {
 		mcount_unguard_recursion(mtdp);
 		return -1;
@@ -1637,7 +1658,7 @@ static int __cygprof_entry(unsigned long parent, unsigned long child)
 			return -1;
 	}
 
-	filtered = mcount_entry_filter_check(mtdp, child, &tr);
+	filtered = mcount_entry_filter_check(mtdp, child, &tr, NULL);
 
 	if (unlikely(mtdp->in_exception)) {
 		unsigned long *frame_ptr;
@@ -1784,7 +1805,7 @@ static void _xray_entry(unsigned long parent, unsigned long child, struct mcount
 			return;
 	}
 
-	filtered = mcount_entry_filter_check(mtdp, child, &tr);
+	filtered = mcount_entry_filter_check(mtdp, child, &tr, NULL);
 
 	if (unlikely(mtdp->in_exception)) {
 		unsigned long *frame_ptr;
@@ -2068,9 +2089,11 @@ static __used void mcount_startup(void)
 		mcount_filter_setting.ptype = parse_filter_pattern(pattern_str);
 
 	if (patch_str)
-		mcount_return_fn = (unsigned long)dynamic_return;
+		mcount_return_fn = mcount_arch_ops.exit[UFT_ARCH_OPS_DYNAMIC];
 	else
-		mcount_return_fn = (unsigned long)mcount_return;
+		mcount_return_fn = mcount_arch_ops.exit[UFT_ARCH_OPS_MCOUNT];
+
+	plthook_return_fn = mcount_arch_ops.exit[UFT_ARCH_OPS_PLTHOOK];
 
 	mcount_filter_init(&mcount_filter_setting, !!patch_str);
 	mcount_watch_init();
