@@ -1,13 +1,13 @@
 count = 0
 
-def uftrace_begin(args):
+def uftrace_begin(ctx):
     pass
 
-def uftrace_entry(args):
+def uftrace_entry(ctx):
     global count
     count += 1
 
-def uftrace_exit(args):
+def uftrace_exit(ctx):
     pass
 
 def uftrace_end():
