@@ -1,9 +1,10 @@
 def uftrace_begin(ctx):
-    print(ctx["recording"])
+    print(ctx["record"])
     print(ctx["version"])
-    print(ctx["args"])
+    print(ctx["cmds"])
 
 def uftrace_entry(ctx):
     pass
+
 def uftrace_exit(ctx):
     pass
