@@ -1,13 +1,16 @@
-#include <iostream>
 #include <algorithm>
+#include <iostream>
 
-template<typename T> class C {
-public:
-	C(T v, const char *s) {
+template <typename T>
+class C {
+    public:
+	C(T v, const char *s)
+	{
 		construct(v, s);
 	}
 
-	C(const C<T>& t) {
+	C(const C<T> &t)
+	{
 		copy(t.val, t.str);
 	}
 
@@ -18,22 +21,22 @@ public:
 	const char *str;
 };
 
-template<typename T>
+template <typename T>
 void C<T>::construct(T val, const char *str)
 {
 	this->val = val;
 	this->str = str;
 }
 
-template<typename T>
+template <typename T>
 void C<T>::copy(T val, const char *str)
 {
 	this->val = val;
 	this->str = str;
 }
 
-template<typename T>
-C<T> foo(C<T> c1, C<T>& c2, const char *str, float f)
+template <typename T>
+C<T> foo(C<T> c1, C<T> &c2, const char *str, float f)
 {
 	return C<T>(c1.val + c2.val + f, str);
 }
@@ -41,7 +44,7 @@ C<T> foo(C<T> c1, C<T>& c2, const char *str, float f)
 int main()
 {
 	C<int> c1(1, "debug info");
-	C<int> c2(2, (const char *)0x1234);  /* should not crash */
+	C<int> c2(2, (const char *)0x1234); /* should not crash */
 
 	/* 'c1' is passed by value (for each member) */
 	C<int> c3 = foo(c1, c2, "passed by value", 0.001f);
