@@ -2,6 +2,7 @@
 
 import os.path
 import subprocess as sp
+import time
 
 from runtest import TestBase
 
@@ -43,6 +44,8 @@ class TestCase(TestBase):
         self.pr_debug('prerun command: ' + recv_cmd)
         self.recv_p = sp.Popen(recv_cmd.split())
 
+        time.sleep(0.1)
+
         self.subcmd  = 'record'
         self.option  = '--host %s --port %s ' % ('localhost', self.port)
         self.option += '-E %s' % 'linux:schedule'
