@@ -212,11 +212,12 @@ __used static const char uftrace_help[] =
 "  -R, --retval=FUNC@retval   Show function return value\n"
 "      --sample-time=TIME     Show flame graph with this sampling time\n"
 "      --signal=SIG@act[,act,...]   Trigger action on those SIGnal\n"
-"      --sort-column=INDEX    Sort diff report on column INDEX (default: 2)\n"
+"      --sort-column=INDEX    Sort diff report on column INDEX (default: "
+	stringify(OPT_SORT_COLUMN) ")\n"
 "      --srcline              Enable recording source line info\n"
 "      --symbols              Print symbol tables\n"
 "  -s, --sort=KEY[,KEY,...]   Sort reported functions by KEYs (default: "
-	stringify(OPT_SORT_COLUMN) ")\n"
+	stringify(OPT_SORT_KEYS) ")\n"
 "  -S, --script=SCRIPT        Run a given SCRIPT in function entry and exit\n"
 "  -t, --time-filter=TIME     Hide small functions run less than the TIME\n"
 "      --task                 Show task info instead\n"
