@@ -36,6 +36,13 @@ static void snprintf_trigger_read(char *buf, size_t len, enum trigger_read_type
 		snprintf(buf, len, "%s%s", buf[0] ? "|" : "", "pmu-branch");
 }
 
+static void snprintf_trigger_cond(char *buf, size_t len, struct uftrace_filter_cond *cond)
+{
+	const char *op_str[] = { "==", "!=", ">", ">=", "<", "<=" };
+
+	snprintf(buf, len, "arg%d %s %ld", cond->idx, op_str[cond->op], cond->val);
+}
+
 static void print_trigger(struct uftrace_trigger *tr)
 {
 	if (tr->flags & TRIGGER_FL_CLEAR)
@@ -44,9 +51,17 @@ static void print_trigger(struct uftrace_trigger *tr)
 		pr_dbg("\ttrigger: depth %d\n", tr->depth);
 	if (tr->flags & TRIGGER_FL_FILTER) {
 		if (tr->fmode == FILTER_MODE_IN)
-			pr_dbg("\ttrigger: filter IN\n");
+			pr_dbg("\ttrigger: filter IN");
 		else if (tr->fmode == FILTER_MODE_OUT)
-			pr_dbg("\ttrigger: filter OUT\n");
+			pr_dbg("\ttrigger: filter OUT");
+
+		if (tr->cond.idx) {
+			char buf[64];
+
+			snprintf_trigger_cond(buf, sizeof(buf), &tr->cond);
+			pr_dbg("\tif %s", buf);
+		}
+		pr_dbg("\n");
 	}
 	if (tr->flags & TRIGGER_FL_LOC) {
 		if (tr->lmode == FILTER_MODE_IN)
@@ -255,14 +270,18 @@ void update_trigger(struct uftrace_filter *filter, struct uftrace_trigger *tr, b
 
 	if (tr->flags & TRIGGER_FL_CLEAR) {
 		filter->trigger.flags &= ~tr->clear_flags;
-		if (tr->clear_flags & TRIGGER_FL_FILTER)
+		if (tr->clear_flags & TRIGGER_FL_FILTER) {
 			tr->fmode = filter->trigger.fmode; /* read from tree before deleting */
+			memset(&filter->trigger.cond, 0, sizeof(tr->cond));
+		}
 	}
 
 	if (tr->flags & TRIGGER_FL_DEPTH)
 		filter->trigger.depth = tr->depth;
-	if (tr->flags & TRIGGER_FL_FILTER)
+	if (tr->flags & TRIGGER_FL_FILTER) {
 		filter->trigger.fmode = tr->fmode;
+		memcpy(&filter->trigger.cond, &tr->cond, sizeof(tr->cond));
+	}
 	if (tr->flags & TRIGGER_FL_LOC)
 		filter->trigger.lmode = tr->lmode;
 
@@ -288,6 +307,26 @@ void update_trigger(struct uftrace_filter *filter, struct uftrace_trigger *tr, b
 		filter->trigger.size = tr->size;
 }
 
+bool uftrace_eval_cond(struct uftrace_filter_cond *cond, long val)
+{
+	switch (cond->op) {
+	case FILTER_OP_EQ:
+		return val == cond->val;
+	case FILTER_OP_NE:
+		return val != cond->val;
+	case FILTER_OP_GT:
+		return val > cond->val;
+	case FILTER_OP_GE:
+		return val >= cond->val;
+	case FILTER_OP_LT:
+		return val < cond->val;
+	case FILTER_OP_LE:
+		return val <= cond->val;
+	default:
+		return false;
+	}
+}
+
 /**
  * prune_void_filter - remove filters without trigger flags from the tree
  * @node - filter node to check
@@ -744,6 +783,57 @@ static int parse_hide_action(char *action, struct uftrace_trigger *tr,
 	return 0;
 }
 
+/* if:arg1==1234, single condition only */
+static int parse_cond_action(char *action, struct uftrace_trigger *tr,
+			     struct uftrace_filter_setting *setting)
+{
+	const char *op_str[] = { "==", "!=", ">", ">=", "<", "<=" };
+	char *expr = action + 3;
+	char *pos;
+	int idx;
+	int op = -1;
+	long val;
+
+	if (strncmp(expr, "arg", 3)) {
+		pr_use("ignoring invalid arg: %s\n", expr);
+		return -1;
+	}
+
+	idx = strtol(expr + 3, &pos, 0);
+	if (idx < 1 || idx > 6) { /* don't support retval */
+		pr_use("only support up to 6 argument for now\n");
+		return -1;
+	}
+
+	while (*pos == ' ')
+		pos++;
+
+	/* reverse order match to find "<=" before "<" */
+	for (size_t k = ARRAY_SIZE(op_str) - 1; k < ARRAY_SIZE(op_str); k--) {
+		if (strncmp(pos, op_str[k], strlen(op_str[k])))
+			continue;
+
+		op = k;
+		pos += strlen(op_str[k]);
+		break;
+	}
+	if (op == -1) {
+		pr_use("ignoring invalid op: %.3s\n", pos);
+		return -1;
+	}
+
+	while (*pos == ' ')
+		pos++;
+
+	val = strtol(pos, NULL, 0);
+
+	tr->cond.idx = idx;
+	tr->cond.op = op;
+	tr->cond.val = val;
+
+	return 0;
+}
+
 static int parse_clear_action(char *action, struct uftrace_trigger *tr,
 			      struct uftrace_filter_setting *setting)
 {
@@ -895,6 +985,11 @@ static const struct trigger_action_parser actions[] = {
 		parse_clear_action,
 		TRIGGER_FL_FILTER | TRIGGER_FL_CALLER,
 	},
+	{
+		"if:",
+		parse_cond_action,
+		TRIGGER_FL_FILTER,
+	},
 };
 
 int setup_trigger_action(char *str, struct uftrace_trigger *tr, char **module,
@@ -2570,4 +2665,124 @@ TEST_CASE(locfilter_match)
 	return TEST_OK;
 }
 
+TEST_CASE(filter_setup_cond)
+{
+	struct uftrace_trigger tr = {};
+	struct uftrace_filter_setting setting = {};
+	char val_str_ok1[] = "foo@filter,if:arg1==1234";
+	char val_str_ok2[] = "foo@filter,if:arg2 !=100";
+	char val_str_ok3[] = "foo@filter,if:arg3>= 5678";
+	char val_str_ok4[] = "foo@filter,if:arg4 < 9876";
+	char val_str_ng1[] = "foo@filter,if:name==1234"; /* named arg not supported */
+	char val_str_ng2[] = "foo@filter,if:fparg1==1234"; /* fparg not supported */
+	char val_str_ng3[] = "foo@filter,if:arg1~=1234"; /* op not supported */
+	char val_str_ng4[] = "foo@value,if:arg-1==1234"; /* negative arg index */
+	FILE *null_fp = fopen("/dev/null", "w");
+	FILE *saved_fp = outfp;
+
+	pr_dbg("check filter cond: %s\n", val_str_ok1);
+	TEST_EQ(setup_trigger_action(val_str_ok1, &tr, NULL, 0, &setting), 0);
+	TEST_EQ(tr.cond.idx, 1);
+	TEST_EQ(tr.cond.op, FILTER_OP_EQ);
+	TEST_EQ(tr.cond.val, 1234);
+
+	pr_dbg("check filter cond: %s\n", val_str_ok2);
+	TEST_EQ(setup_trigger_action(val_str_ok2, &tr, NULL, 0, &setting), 0);
+	TEST_EQ(tr.cond.idx, 2);
+	TEST_EQ(tr.cond.op, FILTER_OP_NE);
+	TEST_EQ(tr.cond.val, 100);
+
+	pr_dbg("check filter cond: %s\n", val_str_ok3);
+	TEST_EQ(setup_trigger_action(val_str_ok3, &tr, NULL, 0, &setting), 0);
+	TEST_EQ(tr.cond.idx, 3);
+	TEST_EQ(tr.cond.op, FILTER_OP_GE);
+	TEST_EQ(tr.cond.val, 5678);
+
+	pr_dbg("check filter cond: %s\n", val_str_ok4);
+	TEST_EQ(setup_trigger_action(val_str_ok4, &tr, NULL, 0, &setting), 0);
+	TEST_EQ(tr.cond.idx, 4);
+	TEST_EQ(tr.cond.op, FILTER_OP_LT);
+	TEST_EQ(tr.cond.val, 9876);
+
+	memset(&tr, 0, sizeof(tr));
+	/* suppress usage error messages */
+	if (!debug)
+		outfp = null_fp;
+
+	TEST_NE(setup_trigger_action(val_str_ng1, &tr, NULL, 0, &setting), 0);
+	TEST_NE(setup_trigger_action(val_str_ng2, &tr, NULL, 0, &setting), 0);
+	TEST_NE(setup_trigger_action(val_str_ng3, &tr, NULL, 0, &setting), 0);
+	TEST_NE(setup_trigger_action(val_str_ng4, &tr, NULL, 0, &setting), 0);
+
+	if (!debug)
+		outfp = saved_fp;
+
+	/* failed function should not set any fields */
+	TEST_EQ(tr.cond.idx, 0);
+	TEST_EQ(tr.cond.op, 0);
+	TEST_EQ(tr.cond.val, 0);
+
+	return TEST_OK;
+}
+
+TEST_CASE(filter_eval_cond)
+{
+	struct uftrace_filter_cond cond;
+
+	pr_dbg("check filter cond: arg == 1\n");
+	cond.op = FILTER_OP_EQ;
+	cond.val = 1;
+
+	TEST_EQ(uftrace_eval_cond(&cond, 1), true);
+	TEST_EQ(uftrace_eval_cond(&cond, 2), false);
+
+	pr_dbg("check filter cond: arg == -1\n");
+	cond.op = FILTER_OP_EQ;
+	cond.val = -1;
+
+	TEST_EQ(uftrace_eval_cond(&cond, 1), false);
+	TEST_EQ(uftrace_eval_cond(&cond, -1), true);
+
+	pr_dbg("check filter cond: arg != 1\n");
+	cond.op = FILTER_OP_NE;
+	cond.val = 1;
+
+	TEST_EQ(uftrace_eval_cond(&cond, 1), false);
+	TEST_EQ(uftrace_eval_cond(&cond, 0), true);
+
+	pr_dbg("check filter cond: arg > 10\n");
+	cond.op = FILTER_OP_GT;
+	cond.val = 10;
+
+	TEST_EQ(uftrace_eval_cond(&cond, 11), true);
+	TEST_EQ(uftrace_eval_cond(&cond, 10), false);
+	TEST_EQ(uftrace_eval_cond(&cond, -1), false);
+
+	pr_dbg("check filter cond: arg >= 10\n");
+	cond.op = FILTER_OP_GE;
+	cond.val = 10;
+
+	TEST_EQ(uftrace_eval_cond(&cond, 11), true);
+	TEST_EQ(uftrace_eval_cond(&cond, 10), true);
+	TEST_EQ(uftrace_eval_cond(&cond, 9), false);
+
+	pr_dbg("check filter cond: arg < 0\n");
+	cond.op = FILTER_OP_LT;
+	cond.val = 0;
+
+	TEST_EQ(uftrace_eval_cond(&cond, 1), false);
+	TEST_EQ(uftrace_eval_cond(&cond, 0), false);
+	TEST_EQ(uftrace_eval_cond(&cond, -1), true);
+
+	pr_dbg("check filter cond: arg <= 0\n");
+	cond.op = FILTER_OP_LE;
+	cond.val = 0;
+
+	TEST_EQ(uftrace_eval_cond(&cond, 1), false);
+	TEST_EQ(uftrace_eval_cond(&cond, 0), true);
+	TEST_EQ(uftrace_eval_cond(&cond, -1), true);
+
+	return TEST_OK;
+}
+
 #endif /* UNIT_TEST */
